@@ -42,7 +42,7 @@ template <typename Float>
 gmix::Array<Float>
 list_to_array(const py::list& list) {
     // Assume it's 1D
-    const int size = py::len(list);
+    const size_t size = py::len(list);
 
     gmix::Array<Float> array(size);
     for (int i = 0; i < size; ++i) {
